Trait ThirtyTwoByteHash
pub trait ThirtyTwoByteHash {
// Required method
fn into_32(self) -> [u8; 32];
}Expand description
Trait describing something that promises to be a 32-byte random number; in particular,
it has negligible probability of being zero or overflowing the group order. Such objects
may be converted to Messages without any error paths.
Required Methods
Implementors
impl ThirtyTwoByteHash for breez_sdk_core::bitcoin::hashes::sha256::Hash
Available on crate feature
bitcoin_hashes only.impl ThirtyTwoByteHash for breez_sdk_core::bitcoin::hashes::sha256d::Hash
Available on crate feature
bitcoin_hashes only.impl ThirtyTwoByteHash for LegacySighash
impl ThirtyTwoByteHash for SegwitV0Sighash
impl ThirtyTwoByteHash for TapSighash
impl<T> ThirtyTwoByteHash for breez_sdk_core::bitcoin::hashes::sha256t::Hash<T>where
T: Tag,
Available on crate feature
bitcoin_hashes only.